@@ -15,6 +15,8 @@ E_API Ecore_X_Atom ATM_ENLIGHTENMENT_SCALE = 0;
 E_API Ecore_X_Atom ATM_NETWM_SHOW_WINDOW_MENU = 0;
 E_API Ecore_X_Atom ATM_NETWM_PERFORM_BUTTON_ACTION = 0;
 E_API Ecore_X_Atom ATM_GTK_FRAME_EXTENTS = 0;
+
+E_API Ecore_X_Atom ATM_STEAM_GAME = 0;
 #endif
 
 EINTERN void
@@ -34,6 +36,7 @@ e_hints_init(Ecore_Window root, Ecore_Window propwin)
       "_NET_WM_SHOW_WINDOW_MENU",
       "_NET_WM_PERFORM_BUTTON_ACTION",
       "_GTK_FRAME_EXTENTS",
+      "STEAM_GAME",
    };
    Ecore_X_Atom atoms[EINA_C_ARRAY_LENGTH(atom_names)];
    Ecore_X_Atom supported[46];
@@ -53,6 +56,7 @@ e_hints_init(Ecore_Window root, Ecore_Window propwin)
    ATM_NETWM_SHOW_WINDOW_MENU = atoms[6];
    ATM_NETWM_PERFORM_BUTTON_ACTION = atoms[7];
    ATM_GTK_FRAME_EXTENTS = atoms[8];
+   ATM_STEAM_GAME = atoms[9];
 
    supported_num = 0;
    /* Set what hints we support */
@@ -149,7 +153,7 @@ e_hints_init(Ecore_Window root, Ecore_Window propwin)
         for (;; )
           {
              Ecore_X_Window selfwin = 0;
-             
+
              /* check that supporting wm win points to itself to be valid */
              nwins = ecore_x_window_prop_window_get(twin,
                                                     ECORE_X_ATOM_NET_SUPPORTING_WM_CHECK,
@@ -361,7 +365,7 @@ e_hints_client_stacking_set(void)
                   break;
                }
           }
-        
+
         if (i < c - non_x)
           {
 #ifdef CLIENT_STACK_DEBUG
@@ -670,7 +674,8 @@ e_hints_window_type_set(E_Client *ec)
    (void)ec;
 #else
    if (!e_client_has_xwindow(ec)) return;
-   ecore_x_netwm_window_type_set(e_client_util_win_get(ec), ec->netwm.type);
+   ecore_x_netwm_window_type_set(e_client_util_win_get(ec),
+                                 (Ecore_X_Window_Type)ec->netwm.type);
 #endif
 }
 
@@ -696,12 +701,12 @@ e_hints_window_type_get(E_Client *ec)
    else
      {
         j = 0;
-        ec->netwm.type = types[j];
+        ec->netwm.type = (E_Window_Type)types[j];
         j++;
         while ((j < num) &&
                (ec->netwm.type == E_WINDOW_TYPE_UNKNOWN))
           {
-             ec->netwm.type = types[j];
+             ec->netwm.type = (E_Window_Type)types[j];
              j++;
           }
         if (num > j)
@@ -711,7 +716,7 @@ e_hints_window_type_get(E_Client *ec)
              if (ec->netwm.extra_types)
                {
                   for (i = j, k = 0; i < num; i++, k++)
-                    ec->netwm.extra_types[k] = types[i];
+                    ec->netwm.extra_types[k] = (E_Window_Type)types[i];
                   ec->netwm.extra_types_num = num - j;
                }
           }
@@ -1605,6 +1610,22 @@ e_hints_window_qtopia_soft_menus_get(E_Client *ec)
 #endif
 }
 
+E_API void
+e_hints_window_steam_game_get(E_Client *ec)
+{
+#ifdef HAVE_WAYLAND_ONLY
+   (void)ec;
+#else
+   unsigned int val;
+
+   if (!e_client_has_xwindow(ec)) return;
+   if (ecore_x_window_prop_card32_get(e_client_util_win_get(ec), ATM_STEAM_GAME, &val, 1))
+     ec->steam.steam_game_id = val;
+   else
+     ec->steam.steam_game_id = 0;
+#endif
+}
+
 E_API void
 e_hints_window_virtual_keyboard_state_get(E_Client *ec)
 {
