@@ -40,7 +40,7 @@ e_ipc_init(void)
         else
           ERR("XDG_RUNTIME_DIR of '%s' cannot be accessed", tmp);
      }
-   
+
    tmp = getenv("SD_USER_SOCKETS_DIR");
    if (tmp)
      {
@@ -187,9 +187,7 @@ _e_ipc_cb_client_data(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
          switch (e->minor)
            {
             case E_ALERT_OP_RESTART:
-              if (getenv("E_START_MTRACK"))
-                e_util_env_set("MTRACK", "track");
-              ecore_app_restart();
+              exit(111);
               break;
 
             case E_ALERT_OP_EXIT:
