@@ -79,7 +79,6 @@ static int       _e_main_dirs_init(void);
 static int       _e_main_dirs_shutdown(void);
 static int       _e_main_path_init(void);
 static int       _e_main_path_shutdown(void);
-static void      _e_main_test_formats(void);
 static int       _e_main_screens_init(void);
 static int       _e_main_screens_shutdown(void);
 static void      _e_main_desk_save(void);
@@ -181,22 +180,7 @@ _xdg_data_dirs_augment(void)
         e_util_env_set("XDG_CONFIG_DIRS", buf);
      }
 
-   if (!getenv("XDG_RUNTIME_DIR"))
-     {
-        const char *dir;
-
-        snprintf(buf, sizeof(buf), "/tmp/xdg-XXXXXX");
-        dir = mkdtemp(buf);
-        if (!dir) dir = "/tmp";
-        else
-          {
-             char buf2[4096];
-
-             e_util_env_set("XDG_RUNTIME_DIR", dir);
-             snprintf(buf2, sizeof(buf2), "%s/.e-deleteme", dir);
-             ecore_file_mkdir(buf2);
-          }
-     }
+   // N.B. XDG_RUNTIME_DIR is taken care of in e_start
 
    /* set menu prefix so we get our e menu */
    if (!getenv("XDG_MENU_PREFIX"))
@@ -206,10 +190,46 @@ _xdg_data_dirs_augment(void)
 }
 
 static Eina_Bool
-_e_main_shelf_init_job(void *data EINA_UNUSED)
+_precache_file(const Eina_Hash *hash EINA_UNUSED, const void *key, void *data EINA_UNUSED, void *fdata)
 {
-   e_shelf_config_update();
-   return ECORE_CALLBACK_CANCEL;
+   Eina_List **precache_files = fdata;
+   *precache_files = eina_list_append(*precache_files, strdup(key));
+   return EINA_TRUE;
+}
+
+static void *
+_precache_thread(void *data, Eina_Thread thr EINA_UNUSED)
+{
+   Eina_List *precache_files = data;
+   char *path;
+   double t = ecore_time_get();
+   unsigned int sum = 0;
+   unsigned int reads = 0;
+
+
+   EINA_LIST_FREE(precache_files, path)
+     {
+        double tt = ecore_time_get();
+        FILE *f = fopen(path, "r");
+        unsigned char buf[4096];
+
+        if (f)
+          {
+             size_t sz;
+
+             while ((sz = fread(buf, 1, sizeof(buf), f)) > 0)
+               {
+                  reads ++;
+                  sum = ((sum << 1) ^ buf[0]) + reads;
+               }
+             fclose(f);
+          }
+        printf("PRECACHE: [%1.5f] [%s] DONE\n", ecore_time_get() - tt, path);
+        free(path);
+     }
+   printf("PRECACHE: TOTAL [%1.5f]\n", ecore_time_get() - t);
+   printf("PRECACHE: SUM=%08x, READS=%i\n", sum, reads);
+   return NULL;
 }
 
 /* externally accessible functions */
@@ -220,8 +240,7 @@ main(int argc, char **argv)
    Eina_Bool safe_mode = EINA_FALSE;
    Eina_Bool waslocked = EINA_FALSE;
    Eina_Stringshare *strshare;
-   double t = 0.0, tstart = 0.0;
-   char *s = NULL, buff[32];
+   char *s = NULL;
    struct sigaction action;
 
 #ifdef __linux__
@@ -231,7 +250,7 @@ main(int argc, char **argv)
 #  endif
 # endif
 #endif
-   
+
 #ifdef TS_DO
    t0 = t1 = t2 = ecore_time_unix_get();
 #endif
@@ -272,30 +291,16 @@ main(int argc, char **argv)
 	TS("Signal Trap Done");
      }
 
-   t = ecore_time_unix_get();
-   s = getenv("E_START_TIME");
-   if ((s) && (!getenv("E_RESTART_OK")))
-     {
-        tstart = atof(s);
-        if ((t - tstart) < 5.0) safe_mode = EINA_TRUE;
-     }
-   tstart = t;
-   snprintf(buff, sizeof(buff), "%1.1f", tstart);
-   e_util_env_set("E_START_TIME", buff);
-
-   if (getenv("E_START_MTRACK"))
-     e_util_env_set("MTRACK", NULL);
    TS("Eina Init");
-   s = getenv("EINA_STATGEN");
-   if (!s) e_util_env_set("EINA_STATGEN", "1");
    if (!eina_init())
      {
         e_error_message_show(_("Enlightenment cannot initialize Eina!\n"));
         _e_main_shutdown(-1);
      }
-   if (!s) e_util_env_set("EINA_STATGEN", NULL);
+   eina_file_statgen_enable();
 
    _e_main_shutdown_push(eina_shutdown);
+
    if (!e_log_init())
      {
         e_error_message_show(_("Enlightenment could not create a logging domain!\n"));
@@ -324,6 +329,10 @@ main(int argc, char **argv)
      }
    TS("Determine Prefix Done");
 
+   /* Eio's eio_init internally calls efreet_init. Set XDG_MENU_PREFIX here      */
+   /* else efreet's efreet_menu_prefix symbol is set erroneously during eio_init. */
+   _xdg_data_dirs_augment();
+
    /* for debugging by redirecting stdout of e to a log file to tail */
    setvbuf(stdout, NULL, _IONBF, 0);
 
@@ -334,7 +343,10 @@ main(int argc, char **argv)
    e_util_env_set("E_RESTART_OK", NULL);
    e_util_env_set("PANTS", "ON");
    e_util_env_set("DESKTOP", "Enlightenment");
-
+   if (getenv("E_ALERT_FONT_DIR"))
+     e_util_env_set("E_ALERT_FONT_DIR", NULL);
+   if (getenv("E_ALERT_SYSTEM_BIN"))
+     e_util_env_set("E_ALERT_SYSTEM_BIN", NULL);
    strshare = eina_stringshare_printf("%s/enlightenment_askpass",
                                       e_prefix_bin_get());
    if (strshare)
@@ -368,7 +380,11 @@ main(int argc, char **argv)
      }
    TS("Ecore Init Done");
    _e_main_shutdown_push(ecore_shutdown);
+
+   TS("E Comp Canvas Intercept Init");
    e_comp_canvas_intercept();
+   TS("E Comp Canvas Intercept Init Done");
+
    e_first_frame = getenv("E_FIRST_FRAME");
    if (e_first_frame && e_first_frame[0])
      e_first_frame_start_time = ecore_time_get();
@@ -384,10 +400,6 @@ main(int argc, char **argv)
    TS("EFX Init Done");
    _e_main_shutdown_push((void*)e_efx_shutdown);
 
-   /* Eio's eio_init internally calls efreet_init. Set XDG_MENU_PREFIX here      */
-   /* else efreet's efreet_menu_prefix symbol is set erroneously during eio_init. */
-   _xdg_data_dirs_augment();
-
    TS("EIO Init");
    if (!eio_init())
      {
@@ -604,6 +616,7 @@ main(int argc, char **argv)
 
    s = getenv("E_DESKLOCK_LOCKED");
    if ((s) && (!strcmp(s, "locked"))) waslocked = EINA_TRUE;
+   putenv("E_DESKLOCK_LOCKED=");
 
    TS("E Paths Init");
    if (!_e_main_path_init())
@@ -615,13 +628,57 @@ main(int argc, char **argv)
    TS("E Paths Init Done");
    _e_main_shutdown_push(_e_main_path_shutdown);
 
+   TS("E_Precache");
+   if (!getenv("E_NO_PRECACHE"))
+     {
+        const Eina_List *l;
+        const Eina_List *theme_items = elm_theme_list_get(NULL);
+        Eina_List *precache_files = NULL;
+        Eina_Hash *files = eina_hash_string_superfast_new(NULL);
+        Eina_Thread thr;
+        int scr, dx, dy;
+        // find all theme edj files to precache
+        EINA_LIST_FOREACH(theme_items, l, s)
+          {
+             Eina_Bool search = EINA_FALSE;
+             char *path = elm_theme_list_item_path_get(s, &search);
+             if (path)
+               {
+                  eina_hash_del(files, path, files);
+                  eina_hash_add(files, path, files);
+                  free(path);
+               }
+          }
+        // go over the first 4 screens and all desks and find possible
+        // background files and add them to our hash to precache
+        for (scr = 0; scr < 4; scr++)
+          {
+             for (dy = 0; dy < e_config->zone_desks_y_count; dy++)
+               {
+                  for (dx = 0; dx < e_config->zone_desks_x_count; dx++)
+                    {
+                       const char *bgfile = e_bg_file_get(scr, dx, dy);
+                       eina_hash_del(files, bgfile, files);
+                       eina_hash_add(files, bgfile, files);
+                       eina_stringshare_del(bgfile);
+                    }
+               }
+          }
+        eina_hash_foreach(files, _precache_file, &precache_files);
+        eina_hash_free(files);
+        if (!eina_thread_create(&thr, EINA_THREAD_BACKGROUND, -1,
+                                _precache_thread, precache_files))
+          {
+             ERR("Can't spawn file precache thread");
+          }
+     }
+   TS("E_Precache Done");
+
    TS("E_Ipc Init");
    if (!e_ipc_init()) _e_main_shutdown(-1);
    TS("E_Ipc Init Done");
    _e_main_shutdown_push(e_ipc_shutdown);
 
-   edje_frametime_set(1.0 / e_config->framerate);
-
    TS("E_Font Init");
    if (!e_font_init())
      {
@@ -649,8 +706,6 @@ main(int argc, char **argv)
    TS("E_Moveresize Init Done");
    _e_main_shutdown_push(e_moveresize_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Message Bus"));
    TS("E_Msgbus Init");
    if (!e_msgbus_init())
      {
@@ -677,8 +732,6 @@ main(int argc, char **argv)
    TS("Efreet Init Done");
    _e_main_shutdown_push(efreet_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Starting International Support"));
    TS("E_Intl Post Init");
    if (!e_intl_post_init())
      {
@@ -694,8 +747,6 @@ main(int argc, char **argv)
 
    e_screensaver_preinit();
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Actions"));
    TS("E_Actions Init");
    if (!e_actions_init())
      {
@@ -712,8 +763,15 @@ main(int argc, char **argv)
    e_desk_init();
    e_exehist_init();
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Powersave Modes"));
+   TS("E_System Init");
+   if (!e_system_init())
+     {
+        e_error_message_show(_("Enlightenment cannot initialize the Privilege System access system.\n"));
+        _e_main_shutdown(-1);
+     }
+   TS("E_System Init Done");
+   _e_main_shutdown_push(e_system_shutdown);
+
    TS("E_Powersave Init");
    if (!e_powersave_init())
      {
@@ -723,11 +781,6 @@ main(int argc, char **argv)
    TS("E_Powersave Init Done");
    _e_main_shutdown_push(e_powersave_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Screensaver"));
-
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Screens"));
    TS("Screens Init");
    if (!_e_main_screens_init())
      {
@@ -769,31 +822,27 @@ main(int argc, char **argv)
         _e_main_shutdown_push(e_init_shutdown);
      }
    if (!((!e_config->show_splash) || (after_restart)))
-     e_init_show();
-
-   if (!really_know)
      {
-        TS("Test File Format Support");
-        _e_main_test_formats();
-        TS("Test File Format Support Done");
-     }
-   else
-     {
-        efreet_icon_extension_add(".svg");
-        efreet_icon_extension_add(".jpg");
-        efreet_icon_extension_add(".png");
-        efreet_icon_extension_add(".edj");
+        TS("E_Splash Show");
+        e_init_show();
+        TS("E_Splash Show Done");
      }
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup ACPI"));
+   TS("Add Icon Extensions");
+   efreet_icon_extension_add(".svg");
+   efreet_icon_extension_add(".svgz");
+   efreet_icon_extension_add(".svg.gz");
+   efreet_icon_extension_add(".jpg");
+   efreet_icon_extension_add(".jpeg");
+   efreet_icon_extension_add(".png");
+   efreet_icon_extension_add(".edj");
+   TS("Add Icon Extensions Done");
+
    TS("E_Acpi Init");
    e_acpi_init();
    TS("E_Acpi Init Done");
    _e_main_shutdown_push(e_acpi_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Backlight"));
    TS("E_Backlight Init");
    if (!e_backlight_init())
      {
@@ -802,8 +851,6 @@ main(int argc, char **argv)
      }
    TS("E_Backlight Init Done");
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup DPMS"));
    TS("E_Dpms Init");
    if (!e_dpms_init())
      {
@@ -813,8 +860,6 @@ main(int argc, char **argv)
    TS("E_Dpms Init Done");
    _e_main_shutdown_push(e_dpms_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Desklock"));
    TS("E_Desklock Init");
    if (!e_desklock_init())
      {
@@ -830,14 +875,10 @@ main(int argc, char **argv)
         e_screensaver_update();
      }
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Paths"));
    TS("Efreet Paths");
    _e_main_efreet_paths_init();
    TS("Efreet Paths Done");
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup System Controls"));
    TS("E_Sys Init");
    if (!e_sys_init())
      {
@@ -847,8 +888,6 @@ main(int argc, char **argv)
    TS("E_Sys Init Done");
    _e_main_shutdown_push(e_sys_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Execution System"));
    TS("E_Exec Init");
    if (!e_exec_init())
      {
@@ -861,8 +900,6 @@ main(int argc, char **argv)
    e_comp_all_freeze();
    TS("E_Comp Freeze Done");
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Filemanager"));
    TS("E_Fm2 Init");
    if (!e_fm2_init())
      {
@@ -872,8 +909,6 @@ main(int argc, char **argv)
    TS("E_Fm2 Init Done");
    _e_main_shutdown_push(e_fm2_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Message System"));
    TS("E_Msg Init");
    if (!e_msg_init())
      {
@@ -883,8 +918,6 @@ main(int argc, char **argv)
    TS("E_Msg Init Done");
    _e_main_shutdown_push(e_msg_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Grab Input Handling"));
    TS("E_Grabinput Init");
    if (!e_grabinput_init())
      {
@@ -894,8 +927,6 @@ main(int argc, char **argv)
    TS("E_Grabinput Init Done");
    _e_main_shutdown_push(e_grabinput_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Modules"));
    TS("E_Module Init");
    if (!e_module_init())
      {
@@ -905,8 +936,6 @@ main(int argc, char **argv)
    TS("E_Module Init Done");
    _e_main_shutdown_push(e_module_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Remembers"));
    TS("E_Remember Init");
    if (!e_remember_init(after_restart ? E_STARTUP_RESTART : E_STARTUP_START))
      {
@@ -916,15 +945,11 @@ main(int argc, char **argv)
    TS("E_Remember Init Done");
    _e_main_shutdown_push(e_remember_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Gadgets"));
    TS("E_Gadget Init");
    e_gadget_init();
    TS("E_Gadget Init Done");
    _e_main_shutdown_push((void*)e_gadget_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Gadcon"));
    TS("E_Gadcon Init");
    if (!e_gadcon_init())
      {
@@ -934,8 +959,6 @@ main(int argc, char **argv)
    TS("E_Gadcon Init Done");
    _e_main_shutdown_push(e_gadcon_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Toolbars"));
    TS("E_Toolbar Init");
    if (!e_toolbar_init())
      {
@@ -945,8 +968,6 @@ main(int argc, char **argv)
    TS("E_Toolbar Init Done");
    _e_main_shutdown_push(e_toolbar_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Wallpaper"));
    TS("E_Bg Init");
    if (!e_bg_init())
      {
@@ -956,8 +977,6 @@ main(int argc, char **argv)
    TS("E_Bg Init Done");
    _e_main_shutdown_push(e_bg_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Mouse"));
    TS("E_Mouse Init");
    if (!e_mouse_update())
      {
@@ -966,8 +985,6 @@ main(int argc, char **argv)
      }
    TS("E_Mouse Init Done");
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Bindings"));
    TS("E_Bindings Init");
    if (!e_bindings_init())
      {
@@ -977,8 +994,6 @@ main(int argc, char **argv)
    TS("E_Bindings Init Done");
    _e_main_shutdown_push(e_bindings_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Thumbnailer"));
    TS("E_Thumb Init");
    if (!e_thumb_init())
      {
@@ -1006,8 +1021,6 @@ main(int argc, char **argv)
    TS("E_Update Init Done");
    _e_main_shutdown_push(e_update_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Desktop Environment"));
    TS("E_Deskenv Init");
    if (!e_deskenv_init())
      {
@@ -1017,8 +1030,6 @@ main(int argc, char **argv)
    TS("E_Deskenv Init Done");
    _e_main_shutdown_push(e_deskenv_shutdown);
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup File Ordering"));
    TS("E_Order Init");
    if (!e_order_init())
      {
@@ -1032,12 +1043,6 @@ main(int argc, char **argv)
    e_comp_canvas_keys_grab();
    TS("E_Comp_Canvas Keys Grab Done");
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Load Modules"));
-   TS("Load Modules");
-   _e_main_modules_load(safe_mode);
-   TS("Load Modules Done");
-
    TS("Run Startup Apps");
    if (!nostartup)
      {
@@ -1056,32 +1061,31 @@ main(int argc, char **argv)
    e_test();
    TS("E_Test Done");
 
+   TS("Load Modules");
+   _e_main_modules_load(safe_mode);
+   TS("Load Modules Done");
+
    if (E_EFL_VERSION_MINIMUM(1, 17, 99))
      {
-        if (e_config->show_splash)
-          e_init_status_set(_("Setup Bryces"));
         TS("Bryce Init");
         e_bryce_init();
         TS("Bryce Init Done");
         _e_main_shutdown_push((void*)e_bryce_shutdown);
      }
 
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup Shelves"));
    TS("E_Shelf Init");
    if (!e_shelf_init())
      {
         e_error_message_show(_("Enlightenment cannot set up its module system.\n"));
         _e_main_shutdown(-1);
      }
+   e_shelf_config_update();
    TS("E_Shelf Init Done");
 
-   ecore_idle_enterer_before_add(_e_main_shelf_init_job, NULL);
-
    _idle_after = ecore_idle_enterer_add(_e_main_cb_idle_after, NULL);
 
    if (e_config->show_splash)
-     e_init_status_set(_("Almost Done"));
+     e_init_status_set(_("Welcome to Enlightenment"));
 
    starting = EINA_FALSE;
    inloop = EINA_TRUE;
@@ -1091,6 +1095,11 @@ main(int argc, char **argv)
    if (e_config->show_splash && (!after_restart))
      ecore_timer_add(2.0, _e_main_cb_startup_fake_end, NULL);
 
+   if (after_restart)
+     {
+        E_LIST_FOREACH(e_comp->zones, e_comp_canvas_zone_restarted);
+     }
+
    TS("MAIN LOOP AT LAST");
    if (!setjmp(x_fatal_buff))
      ecore_main_loop_begin();
@@ -1111,10 +1120,8 @@ main(int argc, char **argv)
 
    if (restart)
      {
-        e_util_env_set("E_RESTART_OK", "1");
-        if (getenv("E_START_MTRACK"))
-          e_util_env_set("MTRACK", "track");
-        ecore_app_restart();
+        e_system_shutdown();
+        exit(111); // return code so e_start restrts e freshly
      }
 
    e_prefix_shutdown();
@@ -1138,8 +1145,6 @@ static void
 _e_main_shutdown(int errcode)
 {
    int i = 0;
-   char buf[PATH_MAX];
-   const char *dir;
 
    printf("E: Begin Shutdown Procedure!\n");
 
@@ -1148,12 +1153,6 @@ _e_main_shutdown(int errcode)
    if (_idle_after) ecore_idle_enterer_del(_idle_after);
    _idle_after = NULL;
 
-   dir = getenv("XDG_RUNTIME_DIR");
-   if (dir)
-     {
-        snprintf(buf, sizeof(buf), "%s/.e-deleteme", dir);
-        if (ecore_file_exists(buf)) ecore_file_recursive_rm(dir);
-     }
    for (i = (_e_main_lvl - 1); i >= 0; i--)
      (*_e_main_shutdown_func[i])();
    if (errcode < 0) exit(errcode);
@@ -1545,87 +1544,6 @@ _e_main_path_shutdown(void)
    return 1;
 }
 
-static void
-_e_main_test_formats(void)
-{
-   Evas *evas;
-   Ecore_Evas *ee;
-   Evas_Object *im, *txt;
-   Evas_Coord tw, th;
-   char buff[PATH_MAX];
-   char *types[] =
-   {
-      "svg",
-      "jpg",
-      "png",
-      "edj"
-   };
-   unsigned int i, t_edj = 3;
-
-   if (e_config->show_splash)
-     e_init_status_set(_("Testing Format Support"));
-
-   if (!(ee = ecore_evas_buffer_new(1, 1)))
-     {
-        e_error_message_show(_("Enlightenment found Evas can't create a buffer canvas. Please check\n"
-                               "Evas has Software Buffer engine support.\n"));
-        _e_main_shutdown(-1);
-     }
-   evas = ecore_evas_get(ee);
-   im = evas_object_image_add(evas);
-
-   for (i = 0; i < EINA_C_ARRAY_LENGTH(types); i++)
-     {
-        char b[128], *t = types[i];
-        const char *key = NULL;
-
-        snprintf(b, sizeof(b), "data/images/test.%s", types[i]);
-        e_prefix_data_concat_static(buff, b);
-        if (i == t_edj)
-          {
-             t = "eet";
-             key = "images/0";
-          }
-        evas_object_image_file_set(im, buff, key);
-        switch (evas_object_image_load_error_get(im))
-          {
-           case EVAS_LOAD_ERROR_CORRUPT_FILE:
-           case EVAS_LOAD_ERROR_DOES_NOT_EXIST:
-           case EVAS_LOAD_ERROR_PERMISSION_DENIED:
-             e_error_message_show(_("Enlightenment cannot access test image for '%s' filetype. "
-                                    "Check your install for setup issues.\n"), t);
-             EINA_FALLTHROUGH;
-             // fallthrough anyway as normally these files should work
-
-           case EVAS_LOAD_ERROR_NONE:
-             snprintf(b, sizeof(b), ".%s", types[i]);
-             efreet_icon_extension_add(b);
-             break;
-
-           default:
-             e_error_message_show(_("Enlightenment found Evas can't load '%s' files. "
-                                    "Check Evas has '%s' loader support.\n"), t, t);
-             if (i) _e_main_shutdown(-1);
-             break;
-          }
-     }
-
-   evas_object_del(im);
-
-   txt = evas_object_text_add(evas);
-   evas_object_text_font_set(txt, "Sans", 10);
-   evas_object_text_text_set(txt, "Hello");
-   evas_object_geometry_get(txt, NULL, NULL, &tw, &th);
-   if ((tw <= 0) && (th <= 0))
-     {
-        e_error_message_show(_("Enlightenment found Evas can't load the 'Sans' font. Check Evas has fontconfig\n"
-                               "support and system fontconfig defines a 'Sans' font.\n"));
-        _e_main_shutdown(-1);
-     }
-   evas_object_del(txt);
-   ecore_evas_free(ee);
-}
-
 static int
 _e_main_screens_init(void)
 {
@@ -1643,12 +1561,13 @@ _e_main_screens_init(void)
         e_error_message_show(_("Enlightenment cannot create a compositor.\n"));
         _e_main_shutdown(-1);
      }
+   TS("Compositor Init Done");
 
+   TS("Desk Restore");
    _e_main_desk_restore();
+   TS("Desk Restore Done");
 
 #ifndef HAVE_WAYLAND_ONLY
-   if (e_config->show_splash)
-     e_init_status_set(_("Setup DND"));
    TS("E_Dnd Init");
    if (!e_dnd_init())
      {
@@ -1684,47 +1603,65 @@ _e_main_screens_shutdown(void)
 static void
 _e_main_desk_save(void)
 {
-   const Eina_List *l;
-   char env[1024], name[1024];
-   E_Zone *zone;
-
-   EINA_LIST_FOREACH(e_comp->zones, l, zone)
+#ifndef HAVE_WAYLAND_ONLY
+   if (e_comp_util_has_x())
      {
-        snprintf(name, sizeof(name), "DESK_%d_%d", 0, zone->num);
-        snprintf(env, sizeof(env), "%d,%d", zone->desk_x_current, zone->desk_y_current);
-        e_util_env_set(name, env);
+        const Eina_List *l;
+        E_Zone *zone;
+        char buf[256];
+        unsigned int desk[2];
+        Ecore_X_Atom a;
+
+        EINA_LIST_FOREACH(e_comp->zones, l, zone)
+          {
+             desk[0] = zone->desk_x_current;
+             desk[1] = zone->desk_y_current;
+             snprintf(buf, sizeof(buf), "E_DESK_%i", zone->num);
+             a = ecore_x_atom_get(buf);
+             ecore_x_window_prop_card32_set(e_comp->root, a, desk, 2);
+          }
      }
+#endif
 }
 
 static void
 _e_main_desk_restore(void)
 {
-   const Eina_List *l;
-   E_Zone *zone;
-   E_Client *ec;
-   char *env;
-   char name[1024];
-
-   EINA_LIST_FOREACH(e_comp->zones, l, zone)
+#ifndef HAVE_WAYLAND_ONLY
+   if (e_comp_util_has_x())
      {
+        const Eina_List *l;
+        E_Zone *zone;
+        E_Client *ec;
         E_Desk *desk;
-        int desk_x, desk_y;
+        int ret;
+        char buf[256];
+        unsigned int desks[2];
+        Ecore_X_Atom a;
 
-        snprintf(name, sizeof(name), "DESK_%d_%d", 0, zone->num);
-        env = getenv(name);
-        if (!env) continue;
-        if (!sscanf(env, "%d,%d", &desk_x, &desk_y)) continue;
-        desk = e_desk_at_xy_get(zone, desk_x, desk_y);
-        if (!desk) continue;
-        e_desk_show(desk);
+        EINA_LIST_FOREACH(e_comp->zones, l, zone)
+          {
+             snprintf(buf, sizeof(buf), "E_DESK_%i", zone->num);
+             a = ecore_x_atom_get(buf);
+             ret = ecore_x_window_prop_card32_get(e_comp->root, a, desks, 2);
+             if (ret == 2)
+               {
+                  desk = e_desk_at_xy_get(zone, desks[0], desks[1]);
+                  if (!desk) continue;
+                  e_desk_show(desk);
+               }
+          }
+        E_CLIENT_REVERSE_FOREACH(ec)
+          {
+             if ((!e_client_util_ignored_get(ec)) &&
+                 e_client_util_desk_visible(ec, e_desk_current_get(ec->zone)))
+               {
+                  ec->want_focus = ec->take_focus = 1;
+                  break;
+               }
+          }
      }
-
-   E_CLIENT_REVERSE_FOREACH(ec)
-     if ((!e_client_util_ignored_get(ec)) && e_client_util_desk_visible(ec, e_desk_current_get(ec->zone)))
-       {
-          ec->want_focus = ec->take_focus = 1;
-          break;
-       }
+#endif
 }
 
 static void
@@ -1821,10 +1758,23 @@ _e_main_cb_idle_after(void *data EINA_UNUSED)
    edje_freeze();
 
    if (first_idle)
-     TS("SLEEP");
-   first_idle = 0;
+     {
+        TS("SLEEP");
+        first_idle = 0;
+     }
    e_precache_end = EINA_TRUE;
 
+// every now and again trim malloc memory to stay lean-ish
+#ifdef HAVE_MALLOC_TRIM
+   static double t_last_clean = 0.0;
+   double t = ecore_time_get();
+   if ((t - t_last_clean) > 10.0)
+     {
+        t_last_clean = t;
+        malloc_trim(0);
+     }
+#endif
+
    return ECORE_CALLBACK_RENEW;
 }
 
